==> haskell-cheapskate-0.1.1.2-617-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-B5h3qhkSTAWJkv9bW8rQ8t
key:                  cheapskate-0.1.1.2-B5h3qhkSTAWJkv9bW8rQ8t
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  4cbf63e5c970b82f9fcedd6d3db973c8
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-B5h3qhkSTAWJkv9bW8rQ8t
depends:
    base-4.15.1.0 blaze-html-0.9.1.2-8oL5nWAOswu9DIE2cdBn2W
    containers-0.6.4.1 data-default-0.7.1.1-4W3DdpWCDdz1ZSimKMWhuv
    deepseq-1.4.5.0 mtl-2.2.2 syb-0.7.2.3-HTIpzyBWTd85gpck08Ij6s
    text-1.2.5.0 uniplate-1.6.13-7kew06tVyn8GtuHHGBY8V8
    xss-sanitize-0.3.7.2-35IUEAaewkvBOiuyv4Sx2q

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.2-621-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-3wQWBr9f0gr2NzBC9I45Sp
key:                  cheapskate-0.1.1.2-3wQWBr9f0gr2NzBC9I45Sp
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  2b33cc192f9ab75cb7118478591a3b68
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-3wQWBr9f0gr2NzBC9I45Sp
depends:
    base-4.15.1.0 blaze-html-0.9.1.2-JT9mn2hMnf595zFx9EvPoy
    containers-0.6.4.1 data-default-0.7.1.1-4W3DdpWCDdz1ZSimKMWhuv
    deepseq-1.4.5.0 mtl-2.2.2 syb-0.7.2.3-HnHI7NNT3Te1LokUqmgbA
    text-1.2.5.0 uniplate-1.6.13-CwkSwwItGJCGTH85Ej922e
    xss-sanitize-0.3.7.2-55uEoTChpTeGJK6Xf65tst

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
